import { HttpClient } from "@angular/common/http";
import { Component, OnInit, Inject } from "@angular/core";
import { MatDialogRef, MAT_DIALOG_DATA } from "@angular/material/dialog";
import { ObjectsService } from "@src/app/services/objects.service";
import { DatePipe } from "@angular/common";
import { MatSnackBar } from "@angular/material/snack-bar";
import Viewer from "viewerjs";

@Component({
  selector: "app-six-familiarize",
  templateUrl: "./six-familiarize.component.html",
  styleUrls: ["./six-familiarize.component.scss"],
  providers: [DatePipe],
})
export class SixFamiliarizeComponent implements OnInit {
  constructor(
    public dialogRef: MatDialogRef<SixFamiliarizeComponent>,
    @Inject(MAT_DIALOG_DATA) public data: any,
    private objectsSer: ObjectsService,
    private http: HttpClient,
    private datePipe: DatePipe,
    public snackBar: MatSnackBar
  ) {}

  isEditMode = true;

  ngOnInit(): void {
    console.log('传递的数据',this.data);
    this.isEditMode = this.data.isEditMode;
    this.getData();
  }

  isHttpPost;
  getData() {
    this.http
      .get("/api/SixFamiliars", {
        params: {
          PlanComponentId: this.data.id,
        },
      })
      .subscribe((data: any) => {
        console.log("六熟悉记录数据", data);
        if (data.totalCount === 0) {
          this.isHttpPost = true;
        } else {
          this.isHttpPost = false;
          let item = data.items[0];
          this.familiarizeId = item.id;
          this.memberCount = item.memberCount;
          this.time = [item.startTime, item.endTime];
        }
      });
  }

  isLoading = false;

  memberCount;
  time;
  familiarizeId;
  isLoadingSave = false;
  save() {
    if (!this.isEditMode) {
      this.dialogRef.close();
      return;
    }

    if (!this.memberCount || !this.time) {
      this.snackBar.open("请输入人员数量和熟悉时间", "确定", {
        verticalPosition: "top",
        duration: 3000,
      });
      return;
    }
    this.isLoadingSave = true;
    let body: any = {
      planComponentId: this.data.planData.id,
      memberCount: Number(this.memberCount),
      startTime: this.datePipe.transform(this.time[0], "yyyy-MM-ddTHH:mm:ss"),
      endTime: this.datePipe.transform(this.time[1], "yyyy-MM-ddTHH:mm:ss"),
    };
    if (this.isHttpPost) {
      this.http.post("/api/SixFamiliars", body).subscribe((data: any) => {
        this.familiarizeId = data.id;
        this.isHttpPost = false;
        this.isLoadingSave = false;
        this.snackBar.open("保存成功", "确定", {
          verticalPosition: "top",
          duration: 3000,
        });
        this.dialogRef.close();
      });
    } else {
      body.id = this.familiarizeId;
      this.http.put(`/api/SixFamiliars/${this.familiarizeId}`, body).subscribe(
        (data: any) => {
          this.isLoadingSave = false;
          this.snackBar.open("保存成功", "确定", {
            verticalPosition: "top",
            duration: 3000,
          });
          this.dialogRef.close();
        },
        (err) => {
          this.isLoadingSave = false;
        }
      );
    }
  }

}
