import { Component, OnInit, ViewChild, Inject } from "@angular/core";
import { HttpClient } from "@angular/common/http";
import {
  MatTreeFlatDataSource,
  MatTreeFlattener,
} from "@angular/material/tree";
import { MatPaginator } from "@angular/material/paginator";
import { FlatTreeControl } from "@angular/cdk/tree";
import { FormControl } from "@angular/forms";
import { Router, ActivatedRoute } from "@angular/router";
import { PageEvent } from "@angular/material/paginator";
import {
  MatDialogRef,
  MatDialog,
  MAT_DIALOG_DATA,
} from "@angular/material/dialog";
import { MatSnackBar, MatSnackBarConfig } from "@angular/material/snack-bar";
import { TreeService } from "../../http-interceptors/tree.service";
import { ConstantPool } from "@angular/compiler";
@Component({
  selector: "app-entry-plan",
  templateUrl: "./entry-plan.component.html",
  styleUrls: ["./entry-plan.component.scss"],
})
export class EntryPlanComponent implements OnInit {
  constructor(
    private http: HttpClient,
    private router: Router,
    private route: ActivatedRoute,
    private tree: TreeService,
    public dialog: MatDialog,
    public snackBar: MatSnackBar
  ) {}

  private _transformer = (node, level: number) => {
    //初始化tree
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
      id: node.id,
      parentId: node.parentId,
      children: node.children,
    };
  };
  treeControl = new FlatTreeControl<any>(
    (node) => node.level,
    (node) => node.expandable
  );
  treeFlattener = new MatTreeFlattener(
    this._transformer,
    (node) => node.level,
    (node) => node.expandable,
    (node) => node.children
  );
  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);
  myControl = new FormControl();
  hasChild = (_: number, node: any) => node.expandable;
  //分页
  @ViewChild(MatPaginator, { static: true })
  pageEvent: PageEvent;
  paginator: MatPaginator;
  length: any; //共多少条数据
  pageSize: any; //每页条数
  pageSizeOptions: number[] = [10]; //设置每页条数
  PageNumber: any; //第几页
  IsNewData = ""; //预案维护更新或者新增
  IsNewCompanyData = ""; //单位维护更新或者新增

  displayedColumns: string[] = [
    "unitname",
    "level",
    "jurisdictionsquadron",
    "unittype",
    "plantype",
    "passstate",
    "operation",
  ];
  allorganizations: any; //所有组织机构
  allunittype: any; //所有单位类型
  tabledataSource: any; //表格数据

  organizationName: any; //当前单位组织机构名称
  preparelevels: any;
  integritySort: any; //完整度排序
  haveyuan; //有无预案
  colorRgb(sColor) {
    var reg = /^#([0-9a-fA-f]{3}|[0-9a-fA-f]{6})$/;
    var sColor = sColor.toLowerCase();
    if (sColor && reg.test(sColor)) {
      if (sColor.length === 4) {
        var sColorNew = "#";
        for (var i = 1; i < 4; i += 1) {
          sColorNew += sColor.slice(i, i + 1).concat(sColor.slice(i, i + 1));
        }
        sColor = sColorNew;
      }
      //处理六位的颜色值
      var sColorChange = [];
      for (var i = 1; i < 7; i += 2) {
        sColorChange.push(parseInt("0x" + sColor.slice(i, i + 2)));
      }
      return sColorChange;
    } else {
      return sColor;
    }
  }
  colorHex(rgb) {
    var _this = rgb;
    var reg = /^#([0-9a-fA-f]{3}|[0-9a-fA-f]{6})$/;
    if (/^(rgb|RGB)/.test(_this)) {
      var aColor = _this.replace(/(?:(|)|rgb|RGB)*/g, "").split(",");
      var strHex = "#";
      for (var i = 0; i < aColor.length; i++) {
        var hex: any = Number(aColor[i]).toString(16);
        hex = hex < 10 ? 0 + "" + hex : hex; // 保证每个rgb的值为2位
        if (hex === "0") {
          hex += hex;
        }
        strHex += hex;
      }
      if (strHex.length !== 7) {
        strHex = _this;
      }
      return strHex;
    } else if (reg.test(_this)) {
      var aNum = _this.replace(/#/, "").split("");
      if (aNum.length === 6) {
        return _this;
      } else if (aNum.length === 3) {
        var numHex = "#";
        for (var i = 0; i < aNum.length; i += 1) {
          numHex += aNum[i] + aNum[i];
        }
        return numHex;
      }
    } else {
      return _this;
    }
  }
  gradientColor(startColor, endColor, step) {
    let _this = this;
    let startRGB = _this.colorRgb(startColor); //转换为rgb数组模式
    let startR = startRGB[0];
    let startG = startRGB[1];
    let startB = startRGB[2];

    let endRGB = _this.colorRgb(endColor);
    let endR = endRGB[0];
    let endG = endRGB[1];
    let endB = endRGB[2];

    let sR = (endR - startR) / step; //总差值
    let sG = (endG - startG) / step;
    let sB = (endB - startB) / step;

    var colorArr = [];
    for (var i = 0; i < step; i++) {
      //计算每一步的hex值
      var hex = _this.colorHex(
        "rgb(" +
          parseInt(sR * i + startR) +
          "," +
          parseInt(sG * i + startG) +
          "," +
          parseInt(sB * i + startB) +
          ")"
      );
      colorArr.push(hex);
    }
    return colorArr;
  }
  integrity(width) {
    let _this = this;

    let style: any = {};
    style.width = width + "%";
    if (width < 30) {
      let colorArr = this.gradientColor("#D50000", "#E53935", 30);
      for (let i = 0; i < 30; i++) {
        if (i == width) {
          style.background = colorArr[i];
        }
      }
    }
    if (width >= 30 && width < 60) {
      let colorArr = this.gradientColor("#FF9800", "#E65100", 30);
      for (let i = 30; i < 60; i++) {
        if (i == width) {
          style.background = colorArr[i - 30];
        }
      }
    }
    if (width >= 60) {
      let colorArr = this.gradientColor("#81C784", "#2E7D32", 41);
      for (let i = 60; i <= 100; i++) {
        if (i == width) {
          style.background = colorArr[i - 60];
        }
      }
    }
    return style;
  }
  integrityDetails(width, zong) {
    let style: any = {};
    style.width = (width / zong) * 100 + "%";
    return style;
  }
  level;

  ngOnInit(): void {
    if (window.matchMedia("(max-width: 1400px)").matches) {
      this.pcMore = false;
      this.padMore = true;
      this.pcfind = false;
      this.padjt = true;
    } else {
      this.pcfind = true;
      this.pcMore = true;
      this.padMore = false;
      this.padjt = false;
    }
    this.getunitdata();
    this.getOrganizations();
    this.getUnittype();
    this.getAllPlanInfo();
    this.level = sessionStorage.getItem("level");
    if (this.level == "0") {
      //如果是总队
      this.preparelevels = [
        { name: "总队", value: "1" },
        { name: "支队", value: "2" },
        { name: "大队", value: "4" },
        { name: "中队", value: "8" },
      ];
    }
    if (this.level == "1") {
      //如果是支队
      this.preparelevels = [
        { name: "支队", value: "2" },
        { name: "大队", value: "4" },
        { name: "中队", value: "8" },
      ];
    }
    if (this.level == "2") {
      //如果是大队
      this.preparelevels = [
        { name: "大队", value: "4" },
        { name: "中队", value: "8" },
      ];
    }
    if (this.level == "3") {
      //如果是中队
      this.preparelevels = [{ name: "中队", value: "8" }];
    }
  }
  pcMore; //pc更多
  pcput = false; //pc收起
  pcfind; //pc查询
  padjt = false;
  padMore = true; //pad收缩控制
  padput = false; //pad收起按钮
  imgsrcopen = "../../../assets/images/routdown2.png";
  imgsrcdown = "../../../assets/images/routup2.png";
  pcInfo() {
    this.pcMore = !this.pcMore;
    this.pcput = !this.pcput;
  }
  padInfo() {
    this.padMore = !this.padMore;
    this.padput = !this.padput;
  }

  //得到当前单位信息
  getunitdata() {
    this.http.get("/api/Account/Profiles").subscribe((data: any) => {
      this.organizationName = data.organizationName;
    });
  }
  treedata: any; //组织机构树型数据
  newArr: any = [];
  newallorganizations: any; //用于存储在原始数据基础上的每个机构增加children字段
  //得到当前单位所在组织机构的tree型数据
  getpresentOrganization() {
    this.newallorganizations = this.allorganizations;

    this.newallorganizations.forEach((item) => {
      item.children = [];
      this.newallorganizations.forEach((element) => {
        if (element.parentId == item.id) {
          item.children.push(element);
        }
      });
    });
    this.http.get("/api/Account/Profiles").subscribe((data: any) => {
      this.organizationName = data.organizationName;
      if (this.organizationName) {
        this.newallorganizations.forEach((item) => {
          if (item.name == this.organizationName) {
            this.dataSource.data = [item];
          }
        });
      } else {
        this.dataSource.data = this.tree.toTree(this.treedata);
      }
    });
  }
  //获得所有组织机构
  getOrganizations() {
    this.http.get("/api/Organizations").subscribe((data: any) => {
      this.allorganizations = data;
      this.treedata = this.tree.toTree(data);
      this.getpresentOrganization();
    });
  }
  //获得所有单位类型
  getUnittype() {
    this.http.get("/api/BuildingTypes/Simple").subscribe((data) => {
      this.allunittype = data;
    });
  }

  //分页事件
  chagePage(e) {
    this.PageNumber = e.pageIndex + 1;
    this.getAllPlanInfo();
  }
  //辖区中队div是否显示
  isorganizationbox: boolean = false;
  //点击辖区中队树，将选择的辖区中队添加到变量
  add(node) {
    this.isorganizationbox = false;
    this.js = node.name;
    this.jsId = node.id;
  }
  //打开辖区中队隐藏框
  openorganizationbox() {
    this.isorganizationbox = true;
  }
  //关闭出现的组织机构div
  closediv() {
    this.isorganizationbox = false;
  }
  allPlanInfo: any; //存储所有预案信息
  //获得所有预案信息
  templatePlan: boolean = false; //模板录入预案checkbox
  customPlan: boolean = false; //自定义预案
  getAllPlanInfo() {
    let follow;
    if (!this.isFollowed) {
      follow = "";
    }
    if (this.isFollowed == "0") {
      follow = false;
    }
    if (this.isFollowed == "1") {
      follow = true;
    }

    let planmode = [];
    this.templatePlan ? planmode.push(2) : null;
    this.customPlan ? planmode.push(4) : null;
    let reservePlanType;
    this.reservePlanType
      ? (reservePlanType = JSON.parse(JSON.stringify(this.reservePlanType)))
      : (reservePlanType = "");
    if (this.reservePlanType && this.reservePlanType.length != 0) {
      reservePlanType = eval(this.reservePlanType.join("|"));
    }
    let paramsdata: any = {
      CompanyName: this.companyName || "",
      OrganizationId: this.jsId || "",
      HasChildrenOrganization: this.jscheck || "",
      BuildingTypeId: this.unittype || "",
      PlanType: reservePlanType || "",
      AuditStatus: this.toExamine || "",
      PlanLevel: this.preparelevel || "",
      HasChildrenPlanLevel: this.plcheck || "",
      IsCompanyFollow: follow,
      PageNumber: this.PageNumber || "1",
      PageSize: this.pageSizeOptions[0],
      Sort: this.integritySort ? "integrityscore" : "",
      SortType: this.integritySort || "",
      HasPlanComponents: this.haveyuan || "",
      PlanCategories: this.planCategory,
      IsNewData: this.IsNewData,
      IsNewCompanyData: this.IsNewCompanyData,
      PlanModes: planmode,
    };
    this.http
      .get("/api/Plans", { params: paramsdata })
      .subscribe((data: any) => {
        this.length = data.totalCount;
        this.allPlanInfo = data;
        this.tabledataSource = data.items;
        console.log('预案列表',this.tabledataSource)
      });
  }

  operation = true;
  //查看预案按钮跳转
  routerTo(element) {
    this.level == "0" ? (this.operation = false) : true;
    sessionStorage.setItem("companyName", element.company.name);
    window.open(
      `/planManagement/entryPlandetail?unitId=${
        element.company.id
      }&unitTypeId=${
        element.company.buildingTypes.length == 0
          ? null
          : element.company.buildingTypes[0].id
      }&operation=${this.operation}&pagetype=entryplan&unitName=${
        element.company.name
      }&orName=${element.company.organizationName}&orId=${
        element.company.organizationId
      }&unitType=${
        element.company.buildingTypes.length == 0
          ? null
          : element.company.buildingTypes[0].name
      }&unitAdd=${element.company.address}&usci=${element.company.usci}`
    );
  }
  //查询
  onSubmit(value) {
    this.PageNumber = 1;
    this.pageEvent.pageIndex = 0;
    this.getAllPlanInfo();
  }
  templatePlanChange($event, type) {
    if (type == 1) {
      this.templatePlan = $event;
    } else if (type == 2) {
      this.customPlan = $event;
    }
    if (this.templatePlan || this.customPlan) {
      this.reservePlanType = ["16"];
    } else {
      this.reservePlanType = [];
    }
  }
  companyName: any; //单位名称
  js: any; //所选组织机构
  jsId: any; //所选组织机构的id
  jscheck: boolean; //所选组织机构勾选框
  unittype: any; //单位类型
  reservePlanType: any; //预案类型
  toExamine: any; //审核状态
  preparelevel: any; //编制级别
  plcheck: boolean; //编制级别勾选框
  planCategory = []; //预案级别

  isFollowed; //重点单位
  //重置
  reset() {
    this.IsNewCompanyData = "";
    this.IsNewData = "";
    this.companyName = "";
    this.js = "";
    this.jsId = "";
    this.jscheck = false;
    this.unittype = "";
    this.reservePlanType = "";
    this.toExamine = "";
    this.preparelevel = "";
    this.integritySort = "";
    this.plcheck = false;
    this.haveyuan = "";
    this.isFollowed = "";
    this.planCategory = [];
    //重新获取初始化列表
    // console.log(this.pageEvent)
    this.pageEvent.pageIndex = 0;
    this.PageNumber = 1;

    this.templatePlan = false;
    this.customPlan = false;
    this.getAllPlanInfo();
  }
}
