import { Component, OnInit, Inject } from '@angular/core';
import {MatTreeFlatDataSource, MatTreeFlattener} from '@angular/material/tree';
import {FlatTreeControl} from '@angular/cdk/tree';
import {MatDialog, MatDialogRef, MAT_DIALOG_DATA} from '@angular/material/dialog';
import {FormControl} from '@angular/forms';
import { HttpClient } from '@angular/common/http';
import { TreeService } from '../../http-interceptors/tree.service'
import { MatSnackBar, MatSnackBarConfig } from '@angular/material/snack-bar';
export interface authority {
  id: string,
  name: string,
  value: string,
  order: number,
  parentId: string
}
@Component({
  selector: 'app-authority',
  templateUrl: './authority.component.html',
  styleUrls: ['./authority.component.scss']
})
export class AuthorityComponent implements OnInit {
  
  data:any =[]
  newdata = [];

  private _transformer = (node, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
      id: node.id,
      parentId: node.parentId
    };
  }
  treeControl = new FlatTreeControl<any>(node => node.level, node => node.expandable);
  treeFlattener = new MatTreeFlattener(this._transformer, node => node.level, node => node.expandable, node => node.children);
  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);
  constructor(private http: HttpClient,public dialog: MatDialog,private tree:TreeService) { }

  //重新拉去列表函数
  getlist = ():void=>{
    this.http.get('/api/Permissions').subscribe((data: any[])=>{ 
      this.newdata = this.tree.toTree(data)
      const nodes = this.treeControl.dataNodes;
      const expandNodes = [];
      nodes.forEach((item) => {
        if(item.expandable && this.treeControl.isExpanded(item)){
          expandNodes.push(item.id);
        }
      });
      this.dataSource.data = this.newdata;
      let newNodes = this.treeControl.dataNodes;
      newNodes = newNodes.filter(n => {
        return expandNodes.indexOf(n.id) >= 0;
      });
      newNodes.forEach(item => {
        this.treeControl.expand(item);
      });
    })
  }

  //初始化视图
  ngOnInit() {
    this.http.get('/api/Permissions').subscribe((data: any[])=>{ 
      this.dataSource.data = this.tree.toTree(data)
    })
  }
  hasChild = (_: number, node: any) => node.expandable;

  //创建按钮
  createauthority(value){
    const dialogRef = this.dialog.open(CreateAuthority, {//调用open方法打开对话框并且携带参数过去
      width: '260px',
      data: {id:value.id}
    });
    dialogRef.afterClosed().subscribe(
      data=>{
        if(data){
          this.newdata = []
          this.getlist()
        }   
      }
    );
  }
  //删除按钮
  deleted(authority){
    var isdeleted = confirm("确定要删除此用户吗？")
    if(isdeleted){
      //请求删除接口
      this.newdata = []
      this.http.delete(`/api/Permissions/${authority.id}`).subscribe( data=>{ 
        this.getlist()
      })
    }
  }
}


//创建组件
@Component({
  selector: 'createauthority',
  templateUrl: './createauthority.component.html',
  styleUrls: ['./authority.component.scss']
})
export class CreateAuthority {
  myControl = new FormControl();
  options: string[] = ['0', '1','2', '3','4', '5','6', '7','8'];

  //注入MatDialogRef，可以用来关闭对话框
  //要访问对话框组件中的数据，必须使用MAT_DIALOG_DATA注入令牌
  constructor(private http: HttpClient,public dialogRef: MatDialogRef<CreateAuthority>,public snackBar: MatSnackBar,
    @Inject(MAT_DIALOG_DATA) public data) {}

  onNoClick(): void {
    this.dialogRef.close();
  }
  onSubmit(value){

    if(value.parentId == "null"){
      value.parentId = null
    }
    //编写请求创建用户接口(value是参数)//并且刷新一下
    this.http.post(
      '/api/Permissions', 
      {
        id: '',
        name: value.name,
        value: value.value,
        order: Number(value.order),
        parentId: this.data.id
      }
    ).subscribe(
      data=>{
        this.dialogRef.close(data); 
      },
      err=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('请填写正确格式','确定',config);
      }
    )
  }
}