import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient, HttpHeaders } from '@angular/common/http';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { MatSnackBar, MatSnackBarConfig } from '@angular/material/snack-bar';
import { EventManager } from '@angular/platform-browser';
import { CanvasShareDataService } from 'src/app/canvas-share-data.service';

@Component({
  selector: 'app-leftFunctionalDomain',
  templateUrl: './addPlaneFigure.html',
  styleUrls: ['./panel.scss']
})
export class leftFunctionalDomainComponent implements OnInit {

  constructor(
    private http: HttpClient,
    public dialog: MatDialog,
    public snackBar: MatSnackBar,
    public dialogRef: MatDialogRef<any>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {

  }

  params = { companyId: sessionStorage.getItem('companyId') }
  checked: boolean = false;//是否为避难层

  //提交表单创建平面图
  onSubmit(e) {
    if (!this.data.isBuilding) { //总平面图 创建平面图
      let data = {
        companyId: sessionStorage.getItem('companyId'),
        name: e.name,
        order: this.data.order,
        area: Number(e.area),
        details: e.details,
        enabled: true,
        modifiedTime: new Date(),
      }
      this.http.post('/api/SitePlans', data).subscribe(data => {
        this.dialogRef.close('总平面图');
      })
    } else { //建筑 创建楼层/区域
      let data = {
        isRefugeStorey: e.isRefugeStorey,
        buildingId: this.data.Panel.id,
        name: e.name,
        order: this.data.order,
        area: Number(e.area),
        details: e.details,
        enabled: true,
        modifiedTime: new Date(),
      }
      this.http.post('/api/BuildingAreas', data, { params: this.params }).subscribe(data => {
        this.dialogRef.close('建筑');
      })
    }
  }



}

//编辑平面图 楼层/区域
@Component({
  selector: 'app-editPlaneFigure',
  templateUrl: './editPlaneFigure.html',
  styleUrls: ['./panel.scss']
})
export class editPlaneFigureComponent implements OnInit {

  constructor(private http: HttpClient, public dialog: MatDialog, public snackBar: MatSnackBar, public dialogRef: MatDialogRef<any>, @Inject(MAT_DIALOG_DATA) public data, public canvasData: CanvasShareDataService, private eventManager: EventManager,) { }

  ngOnInit(): void {
    this.name = this.data.buildingData.name || ''
    this.checked = this.data.buildingData.isRefugeStorey || false
    this.area = this.data.buildingData.area || 0
    this.details = this.data.buildingData.details || ''
    this.imgWidth = this.data.buildingData.imageWidth || 0
    this.imgHeight = this.data.buildingData.imageHeight || 0
    this.oldWidth = JSON.parse(JSON.stringify(this.data.buildingData.imageWidth || 0))
    this.oldHeight = JSON.parse(JSON.stringify(this.data.buildingData.imageHeight || 0))
    if (this.imgWidth == 0 && this.imgHeight == 0 && this.data.buildingData.imageUrl) {
      let that = this
      let img = new Image()
      img.src = this.data.buildingData.imageUrl
      img.onload = function () {
        that.imgWidth = img.width
        that.imgHeight = img.height
        that.imgScale = Number((that.imgWidth / that.imgHeight))
      }
    } else {
      this.imgScale = Number((this.imgWidth / this.imgHeight))
    }

    this.eventManager.addGlobalEventListener('window', 'keydown', (event: any) => {
      if (event.keyCode === 13) {
        event.preventDefault();
      }
    });
  }

  oldWidth: number; //原图片宽
  oldHeight: number; //原图片高

  params = { companyId: sessionStorage.getItem('companyId') }
  name: any; //name
  checked: boolean = false;//是否为避难层
  area: number; //面积
  details: string; //详情

  imgWidth: number; //图片宽度
  imgHeight: number; //图片高度
  isItEqual: boolean = true; //是否等比
  imgScale: number; //图片 宽高比例

  //图片 宽高变化时
  inputChange(e) {
    if (this.isItEqual) {
      if (e == 0) { //需要改高度
        this.imgHeight = Math.round(this.imgWidth / this.imgScale)
        this.canvasData.selectStorey.imageWidth = this.imgWidth
        this.canvasData.selectStorey.imageHeight = this.imgHeight
      } else { //需要改宽度
        this.imgWidth = Math.round(this.imgHeight * this.imgScale)
        this.canvasData.selectStorey.imageWidth = this.imgWidth
        this.canvasData.selectStorey.imageHeight = this.imgHeight
      }
    } else {
      this.canvasData.selectStorey.imageWidth = this.imgWidth
      this.canvasData.selectStorey.imageHeight = this.imgHeight
    }
  }

  //重新计算 宽高比例
  setImgScale(e) {
    e.checked ? this.imgScale = Number((this.imgWidth / this.imgHeight)) : null
  }

  //关闭
  close() {
    if (this.oldWidth === this.imgWidth && this.oldHeight === this.imgHeight) {
      this.dialogRef.close()
    } else {
      this.canvasData.selectStorey.imageWidth = this.oldWidth
      this.canvasData.selectStorey.imageHeight = this.oldHeight
      this.dialogRef.close('更新背景图');
    }
  }

  //提交表单修改平面图
  onSubmit(e) {
    if (!this.data.isBuilding) { //总平面图 修改平面图
      let data = {
        companyId: sessionStorage.getItem('companyId'),
        id: this.data.buildingData.id,
        name: e.name,
        cadUrl: this.data.buildingData.cadUrl,
        imageUrl: this.data.buildingData.imageUrl,
        imageWidth: this.imgWidth,
        imageHeight: this.imgHeight,
        imageAngle: this.data.buildingData.imageAngle,
        order: this.data.buildingData.order,
        area: e.area,
        details: e.details,
        enabled: this.data.buildingData.enabled,
        modifiedTime: new Date(),
      }
      this.http.put(`/api/SitePlans/${this.data.buildingData.id}`, data).subscribe(data => {
        this.dialogRef.close('总平面图');
      })
    } else { //建筑 修改楼层/区域
      let data = {
        isRefugeStorey: e.isRefugeStorey,
        buildingId: this.data.Panel.id,
        id: this.data.buildingData.id,
        name: e.name,
        cadUrl: this.data.buildingData.cadUrl,
        imageUrl: this.data.buildingData.imageUrl,
        imageWidth: this.imgWidth,
        imageHeight: this.imgHeight,
        imageAngle: this.data.buildingData.imageAngle,
        order: this.data.buildingData.order,
        area: e.area,
        details: e.details,
        enabled: this.data.buildingData.enabled,
        modifiedTime: new Date(),
      }
      this.http.put(`/api/BuildingAreas/${this.data.buildingData.id}`, data, { params: this.params }).subscribe(data => {
        this.dialogRef.close('建筑');
      })
    }
  }



}



//新建 底图数据节点
@Component({
  selector: 'app-addBGCDisposalNode',
  templateUrl: './addBGCDisposalNode.html',
  styleUrls: ['./panel.scss']
})
export class addBGCDisposalNodeComponent implements OnInit {

  constructor(private http: HttpClient, public dialog: MatDialog, public snackBar: MatSnackBar, public dialogRef: MatDialogRef<any>, @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void { }

  file: any = null; //文件
  //上传图片
  selectFile(e) {
    if (e.target.files.length) {
      let maxSize = 100 * 1024 * 1024
      if (e.target.files[0].size <= maxSize) {
        this.file = e.target.files[0]
      } else {
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('上传图片需小于100MB', '确定', config);
      }
    }
  }

  //提交表单
  onSubmit(e) {
    if (e.name && this.file) {
      if (this.file.name.toLowerCase().indexOf('png') == -1 && this.file.name.toLowerCase().indexOf('jpg') == -1 && this.file.name.toLowerCase().indexOf('jpeg') == -1) {
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('请上传图片后缀为png,jpg,jpeg的文件', '确定', config);
        return
      }
      e.file = this.file
      this.dialogRef.close(e);
    } else {
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请上传图片', '确定', config);
    }
  }

}



//创建 处置预案 节点
@Component({
  selector: 'app-addDisposalNode',
  templateUrl: './addDisposalNode.html',
  styleUrls: ['./panel.scss']
})
export class addDisposalNodeComponent implements OnInit {

  constructor(private http: HttpClient, public dialog: MatDialog, public snackBar: MatSnackBar, public dialogRef: MatDialogRef<any>, @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
  }

  //提交表单
  onSubmit(e) {
    this.data.name = e.name
    this.http.post('/api/DisposalNodes', this.data).subscribe(data => {
      this.dialogRef.close('success');
    })
  }

}



//编辑 处置预案 节点
@Component({
  selector: 'app-editDisposalNode',
  templateUrl: './editDisposalNode.html',
  styleUrls: ['./panel.scss']
})
export class editDisposalNodeComponent implements OnInit {

  constructor(private http: HttpClient, public dialog: MatDialog, public snackBar: MatSnackBar, public dialogRef: MatDialogRef<any>, @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    this.nodeName = JSON.parse(JSON.stringify(this.data.name || ''))
  }
  nodeName: string;

  //提交表单
  onSubmit(e) {
    this.data.name = e.name
    this.http.put(`/api/DisposalNodes/${this.data.id}`, this.data).subscribe(data => {
      this.dialogRef.close(e.name);
    })
  }

}