import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { MatSnackBarConfig, MatSnackBar } from '@angular/material/snack-bar';



@Component({
  selector: 'app-fire-fighting-facilities-formwork',
  templateUrl: './fire-fighting-facilities-formwork.component.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class FireFightingFacilitiesFormworkComponent implements OnInit {

  constructor(private http:HttpClient,public dialog: MatDialog,public snackBar: MatSnackBar) { }
  
  displayedColumn = ['checked','name','isEachFloor','isMerged','operation']
  displayedColumns = ['checked','name', 'type', 'default','required','physicalUnit','operation'];

  ngOnInit(): void {
    this.http.get('/api/FacilityCategories').subscribe(data=>{
      this.allFireProtectionFacilities = data
      this.selectFireProtectionFacilities = data[0]
      this.getBuiltInGrouping()
      this.getOptionalGrouping()
    })
  }

  allFireProtectionFacilities:any = []; //所有的消防设施模板
  selectFireProtectionFacilities:any; //选中的消防设施模板
  FireProtectionFacilitiesIndex:any = 0; //选中的消防设施模板下标
  builtInGrouping:any = []; //当前模板的内置分组
  optionalGrouping:any = []; //当前模板的可选分组

  //获取所有的消防设施模板
  getAllTemplate () {
    this.http.get('/api/FacilityCategories').subscribe(data=>{
      this.allFireProtectionFacilities = data
      this.selectFireProtectionFacilities = data[this.FireProtectionFacilitiesIndex]
    })
  }

  //获取当前模板内置分组
  getBuiltInGrouping () {
    if (this.selectFireProtectionFacilities){
      let id = {categoryId: this.selectFireProtectionFacilities.id}
      this.http.get(`/api/FacilityGroups`,{params:id}).subscribe(data=>{
        this.builtInGrouping = data
        this.selectBuiltIn = []
      })
    }
  }

  //获取当前模板可选分组
  getOptionalGrouping () {
    if (this.selectFireProtectionFacilities){
      let id = {categoryId: this.selectFireProtectionFacilities.id}
      this.http.get(`/api/OptionalGroups`,{params:id}).subscribe(data=>{
        this.optionalGrouping = data
        this.selectOptional = []
      })
    }
  }

  //切换左侧模板时
  selectFire (e,index) {
    if (this.FireProtectionFacilitiesIndex != index) {
      this.selectFireProtectionFacilities = e
      this.FireProtectionFacilitiesIndex = index
      this.selectBuiltIn = []
      this.selectOptional = []
      this.getBuiltInGrouping()
      this.getOptionalGrouping()
    }
  }

  //新增消防设施模板
  addTemplate () {
    const dialogRef = this.dialog.open(addFireFightingFacilitiesFormworkComponent,{});
    dialogRef.afterClosed().subscribe(data=>{
      if (data) {this.getAllTemplate()}
    });
  }

  //编辑消防设施模板
  editTemplate () {
    if (this.selectFireProtectionFacilities) {
      let data = this.selectFireProtectionFacilities
      const dialogRef = this.dialog.open(editFireFightingFacilitiesFormworkComponent,{data});
      dialogRef.afterClosed().subscribe(data=>{
        if (data) {this.getAllTemplate()}
      });
    }
  }

  //禁启用消防设施模板
  enabledTemplate () {
    if (this.selectFireProtectionFacilities) {
      let data = this.selectFireProtectionFacilities
      if (data.enabled) {
        let newDate = {
          id: data.id,
          name: data.name,
          enabled: false}
        this.http.put(`/api/FacilityCategories/${data.id}`,newDate).subscribe(data=>{
          this.getAllTemplate()})
      } else{
        let newDate = {
          id: data.id,
          name: data.name,
          enabled: true}
        this.http.put(`/api/FacilityCategories/${data.id}`,newDate).subscribe(data=>{
          this.getAllTemplate()})
      }
    }
  }

  //删除消防设施模板
  deleteTemplate () {
    if (this.selectFireProtectionFacilities) {
     let isDelete = confirm('您确定要删除吗')
     if (isDelete) {
      this.http.delete(`/api/FacilityCategories/${this.selectFireProtectionFacilities.id}`).subscribe(data=>{
        this.http.get('/api/FacilityCategories').subscribe(data=>{
          this.allFireProtectionFacilities = data
          this.selectFireProtectionFacilities = data[this.FireProtectionFacilitiesIndex]
          this.builtInGrouping = []
          this.optionalGrouping = []
          this.getBuiltInGrouping()
          this.getOptionalGrouping()   })//http.get
      })
     }
    }
  }

  //新增内置分组
  addBuiltIn () {
    if (this.selectFireProtectionFacilities) {
      let data = {template:this.selectFireProtectionFacilities, order:this.builtInGrouping[this.builtInGrouping.length-1]}
      const dialogRef = this.dialog.open(addBuiltInComponent,{data});
      dialogRef.afterClosed().subscribe(data=>{
        if (data) {this.getBuiltInGrouping()}
      });
    }
  }

  //禁启用内置分组
  enabledBuilt (e) {
    if (e.enabled) {
      let data = {
        id: e.id,
        name: e.name,
        order:e.order,
        enabled: false,
        facilityItems: e.facilityItems,
        facilityCategoryId: e.facilityCategoryId}
      this.http.put(`/api/FacilityGroups/${e.id}`,data).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('禁用成功','确定',config);
        this.getBuiltInGrouping()
      })
    } else {
      let data = {
        id: e.id,
        name: e.name,
        order:e.order,
        enabled: true,
        facilityItems: e.facilityItems,
        facilityCategoryId: e.facilityCategoryId}
      this.http.put(`/api/FacilityGroups/${e.id}`,data).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('启用成功','确定',config);
        this.getBuiltInGrouping()
      })
    }
  }

  //删除内置分组
  deleteBuilt (e) {
    let isDelete = confirm('您确定要删除吗')
    if (isDelete) {
      this.http.delete(`/api/FacilityGroups/${e.id}`).subscribe(data=>{
        this.getBuiltInGrouping()
      })
    }
  }

  //新增内置分组属性
  addBuiltInAttribute (e) {
    let data = e
    const dialogRef = this.dialog.open(addBuiltInAttributeComponent,{data});
    dialogRef.afterClosed().subscribe(data=>{
      if (data) {this.getBuiltInGrouping()}
    });
  }

  //编辑内置分组属性
  editBuiltInAttribute (e,element) {
    let data = {grouping:e, attribute: element}
    const dialogRef = this.dialog.open(editBuiltInAttributeComponent,{data});
    dialogRef.afterClosed().subscribe(data=>{
      if (data) {this.getBuiltInGrouping()}
    });
  }

  //删除内置分组属性
  deleteBuiltInAttribute (e,element){
    let isDelete = confirm('您确定要删除吗')
    if (isDelete) {
      e.facilityItems.splice(e.facilityItems.findIndex(item=>item==element),1)
      this.http.put(`/api/FacilityGroups/${e.id}`,e).subscribe(data=>{
        this.getBuiltInGrouping()
      })
    }
  }

  //内置分组排序
  selectBuiltIn = []; //checked选中的内置分组

  //内置分组change时
  changeBuilt (e,item) {
    if (e.checked) {
      this.selectBuiltIn.push(item)
    } else{this.selectBuiltIn.splice(this.selectBuiltIn.findIndex(items=>items==item),1)}
  }

  //内置分组上移
  topBuilt () {
    if(this.selectBuiltIn.length) {
      let attribute = this.selectBuiltIn[this.selectBuiltIn.length-1] //选中分组最后一项
      let newOrder = attribute.order //选中项的order
      let index = this.builtInGrouping.findIndex(item=>item==attribute) //选中项在数组中的位置
      if (index!=0) {
        this.builtInGrouping[index].order = this.builtInGrouping[index-1].order
        this.http.put(`/api/FacilityGroups/${this.builtInGrouping[index].id}`,this.builtInGrouping[index]).subscribe(data=>{
          this.builtInGrouping[index-1].order = newOrder
          this.http.put(`/api/FacilityGroups/${this.builtInGrouping[index-1].id}`,this.builtInGrouping[index-1]).subscribe(data=>{
            this.getBuiltInGrouping()
          })
        })
      }
    }
  }

  //内置分组下移
  bottomBuilt () {
    if(this.selectBuiltIn.length) {
      let attribute = this.selectBuiltIn[this.selectBuiltIn.length-1] //选中分组最后一项
      let newOrder = attribute.order //最后一项的order
      let index = this.builtInGrouping.findIndex(item=>item==attribute)
      if (index!= this.builtInGrouping.length-1) {
        this.builtInGrouping[index].order = this.builtInGrouping[index+1].order
        this.http.put(`/api/FacilityGroups/${this.builtInGrouping[index].id}`,this.builtInGrouping[index]).subscribe(data=>{
          this.builtInGrouping[index+1].order = newOrder
          this.http.put(`/api/FacilityGroups/${this.builtInGrouping[index+1].id}`,this.builtInGrouping[index+1]).subscribe(data=>{
            this.getBuiltInGrouping()
          })
        })
      }
    }
  }



  //新增可选分组
  addOptional () {
    if (this.selectFireProtectionFacilities) {
      let data = {template:this.selectFireProtectionFacilities, order:this.optionalGrouping[this.optionalGrouping.length-1]}
      const dialogRef = this.dialog.open(addOptionalComponent,{data});
      dialogRef.afterClosed().subscribe(data=>{
        if (data) {this.getOptionalGrouping()}
      });
    }
  }

  //是否可选-可选分组
  isOptional (e) {
    if (e.isOptional) {
      let data = {
        facilityCategoryId: e.facilityCategoryId,
        id: e.id,
        name: e.name,
        type: e.type,
        addMode: e.addMode,
        isOptional: false,
        order: e.order,
        enabled: e.enabled,
        propertyInfos: e.propertyInfos}
      this.http.put(`/api/OptionalGroups/${e.id}`,data).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('现状态为不可选','确定',config);
        this.getOptionalGrouping()
      })
    } else {
      let data = {
        facilityCategoryId: e.facilityCategoryId,
        id: e.id,
        name: e.name,
        type: e.type,
        addMode: e.addMode,
        isOptional: true,
        order: e.order,
        enabled: e.enabled,
        propertyInfos: e.propertyInfos}
      this.http.put(`/api/OptionalGroups/${e.id}`,data).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('现状态为可选','确定',config);
        this.getOptionalGrouping()
      })
    }
  }

  //禁启用可选分组
  enabledOptional (e) {
    if (e.enabled) {
      let data = {
        facilityCategoryId: e.facilityCategoryId,
        id: e.id,
        name: e.name,
        type: e.type,
        addMode: e.addMode,
        isOptional: e.isOptional,
        order: e.order,
        enabled: false,
        propertyInfos: e.propertyInfos}
      this.http.put(`/api/OptionalGroups/${e.id}`,data).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('禁用成功','确定',config);
        this.getOptionalGrouping()
      })
    } else {
      let data = {
        facilityCategoryId: e.facilityCategoryId,
        id: e.id,
        name: e.name,
        type: e.type,
        addMode: e.addMode,
        isOptional: e.isOptional,
        order: e.order,
        enabled: true,
        propertyInfos: e.propertyInfos}
      this.http.put(`/api/OptionalGroups/${e.id}`,data).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('启用成功','确定',config);
        this.getOptionalGrouping()
      })
    }
  }

  //删除可选分组
  deleteOptional (e) {
    let isDelete = confirm('您确定要删除吗')
    if (isDelete) {
      this.http.delete(`/api/OptionalGroups/${e.id}`).subscribe(data=>{
        this.getOptionalGrouping()
      })
    }
  }

  //新增可选分组属性
  addOptionalAttribute (e) {
    let data = e
    const dialogRef = this.dialog.open(addOptionalAttributeComponent,{data});
    dialogRef.afterClosed().subscribe(data=>{
      if (data) {this.getOptionalGrouping()}
    });
  }

  //编辑可选分组属性
  editOptionalAttribute (e,element) {
    let data = {grouping:e, attribute: element}
    const dialogRef = this.dialog.open(editOptionalAttributeComponent,{data});
    dialogRef.afterClosed().subscribe(data=>{
      if (data) {this.getOptionalGrouping()}
    });
  }

  //删除可选分组属性
  deleteOptionalAttribute (e,element) {
    let isDelete = confirm('您确定要删除吗')
    if (isDelete) {
      e.propertyInfos.splice(e.propertyInfos.findIndex(item=>item==element),1)
      this.http.put(`/api/OptionalGroups/${e.id}`,e).subscribe(data=>{
        this.getOptionalGrouping()
      })
    }
  }

  //可选分组排序
  selectOptional = []; //checked选中的可选分组

  //可选分组change时
  changeOptional (e,item) {
    if (e.checked) {
      this.selectOptional.push(item)
    } else{this.selectOptional.splice(this.selectOptional.findIndex(items=>items==item),1)}
  }

  //可选分组上移
  topOptional () {
    if(this.selectOptional.length) {
      let attribute = this.selectOptional[this.selectOptional.length-1] //选中分组最后一项
      let newOrder = attribute.order //选中项的order
      let index = this.optionalGrouping.findIndex(item=>item==attribute) //选中项在数组中的位置
      if (index!=0) {
        this.optionalGrouping[index].order = this.optionalGrouping[index-1].order
        this.http.put(`/api/OptionalGroups/${this.optionalGrouping[index].id}`,this.optionalGrouping[index]).subscribe(data=>{
          this.optionalGrouping[index-1].order = newOrder
          this.http.put(`/api/OptionalGroups/${this.optionalGrouping[index-1].id}`,this.optionalGrouping[index-1]).subscribe(data=>{
            this.getOptionalGrouping()
          })
        })
      }
    }
  }

  //可选分组下移
  bottomOptional () {
    if(this.selectOptional.length) {
      let attribute = this.selectOptional[this.selectOptional.length-1] //选中分组最后一项
      let newOrder = attribute.order //选中项的order
      let index = this.optionalGrouping.findIndex(item=>item==attribute) //选中项在数组中的位置
      if (index!=this.optionalGrouping.length-1) {
        this.optionalGrouping[index].order = this.optionalGrouping[index+1].order
        this.http.put(`/api/OptionalGroups/${this.optionalGrouping[index].id}`,this.optionalGrouping[index]).subscribe(data=>{
          this.optionalGrouping[index+1].order = newOrder
          this.http.put(`/api/OptionalGroups/${this.optionalGrouping[index+1].id}`,this.optionalGrouping[index+1]).subscribe(data=>{
            this.getOptionalGrouping()
          })
        })
      }
    }
  }



}



//新增消防设施模板
@Component({
  selector: 'app-addFireFightingFacilitiesFormwork',
  templateUrl: './addFireFightingFacilitiesFormwork.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class addFireFightingFacilitiesFormworkComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<addFireFightingFacilitiesFormworkComponent>) { }

  ngOnInit(): void {

  }

  //提交表单
  onSubmit (e) {
    let data = {
      name: e.name,
      enabled: true
    }
    this.http.post('/api/FacilityCategories',data).subscribe(data=>{
      this.dialogRef.close(data);
    })
  }

}



//编辑消防设施模板
@Component({
  selector: 'app-editFireFightingFacilitiesFormwork',
  templateUrl: './editFireFightingFacilitiesFormwork.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class editFireFightingFacilitiesFormworkComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<editFireFightingFacilitiesFormworkComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    this.templateName = this.data.name
  }

  templateName:any; //模板名字

  //提交表单
  onSubmit (e) {
    let data = {
      id: this.data.id,
      name: this.templateName,
      enabled: this.data.enabled}
    this.http.put(`/api/FacilityCategories/${this.data.id}`,data).subscribe(data=>{
      this.dialogRef.close('success');
    })
  }

}



//新增消防设施模板内置分组
@Component({
  selector: 'app-addBuiltIn',
  templateUrl: './addBuilt-in.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class addBuiltInComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<addBuiltInComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    if (this.data.order) {
      this.order = this.data.order.order+1
    } else{this.order=0}
  }

  order:number; //order
  //提交表单
  onSubmit (e) {
    let data = {
      name: e.name,
      order: this.order,
      enabled: true,
      facilityItems: [],
      facilityCategoryId: this.data.template.id}
    this.http.post(`/api/FacilityGroups`,data).subscribe(data=>{
      this.dialogRef.close(data)
    })
  }

}



//新增消防设施模板内置分组属性
@Component({
  selector: 'app-addBuiltInAttribute',
  templateUrl: './addBuilt-inAttribute.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class addBuiltInAttributeComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<addBuiltInAttributeComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    if (this.data.facilityItems.length) {
      this.order = this.data.facilityItems[this.data.facilityItems.length-1].order+1
    } else{
      this.order = 0
    }
  }

  order:number; //order

  //提交表单
  onSubmit (e) {
    let newFacilityItems = {name:e.name,isEachFloor:e.isEachFloor=='true'? true: false,order:this.order,isMerged:e.isMerged=='true'? true: false,}
    this.data.facilityItems.push(newFacilityItems)
    let data = {
      id: this.data.id,
      name: this.data.name,
      order: this.data.order,
      enabled: this.data.enabled,
      facilityItems: this.data.facilityItems,
      facilityCategoryId: this.data.facilityCategoryId}
    this.http.put(`/api/FacilityGroups/${this.data.id}`,data).subscribe(data=>{
      this.dialogRef.close('success')
    })
  }

}



//编辑消防设施模板内置分组属性
@Component({
  selector: 'app-editBuiltInAttribute',
  templateUrl: './editBuilt-inAttribute.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class editBuiltInAttributeComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<editBuiltInAttributeComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    this.attributeName = this.data.attribute.name
    this.attributeIsEachFloor = String(this.data.attribute.isEachFloor)
    this.attributeIsMerged = String(this.data.attribute.isMerged)
    this.attributeOrder = this.data.attribute.order
  }

  attributeName:any; //属性名
  attributeIsEachFloor:any; //是否逐层统计
  attributeIsMerged:any; //是否合并
  attributeOrder:number; //属性order

  //提交表单
  onSubmit (e) {
    let data = {
      name: e.name,
      isEachFloor: e.isEachFloor=='true'? true: false,
      isMerged: e.isMerged=='true'? true: false,
      order: e.order}
    this.data.grouping.facilityItems.splice(this.data.grouping.facilityItems.findIndex(item=>item==this.data.attribute),1)
    this.data.grouping.facilityItems.push(data)
    this.http.put(`/api/FacilityGroups/${this.data.grouping.id}`,this.data.grouping).subscribe(data=>{
      this.dialogRef.close('success')
    })
  }



}



//新增消防设施模板可选分组
@Component({
  selector: 'app-addOptional',
  templateUrl: './addOptional.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class addOptionalComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<addOptionalComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    if (this.data.order) {
      this.order = this.data.order.order+1
    } else{this.order=0}
  }

  order:number; //order

  //提交表单
  onSubmit (e) {
    let data = {
      facilityCategoryId: this.data.template.id,
      name: e.name,
      type: Number(e.type),
      addMode: Number(e.addMode),
      isOptional: true,
      order: this.order,
      enabled: true,
      propertyInfos: []
    }
    this.http.post('/api/OptionalGroups',data).subscribe(data=>{
      this.dialogRef.close(data)
    })
  }



}



export interface Food {
  value: number;
  viewValue: string;
}
//新增消防设施模板可选分组属性
@Component({
  selector: 'app-addOptionalAttribute',
  templateUrl: './addOptionalAttribute.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class addOptionalAttributeComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<addOptionalAttributeComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    if (this.data.propertyInfos.length) {
      this.order = this.data.propertyInfos[this.data.propertyInfos.length-1].order+1
    } else{
      this.order = 0
    }
  }

  //定义属性数据
  propertyType:Food[]=[
    {value:0, viewValue: '单行文本'},
    {value:1, viewValue: '多行文本'},
    {value:2, viewValue: '数值'},
    {value:3, viewValue: '图片'},
    {value:4, viewValue: '图片数量'},
    {value:5, viewValue: '方向'},
    {value:6, viewValue: '布尔值'},
    {value:7, viewValue: '供给区域'},
    {value:8, viewValue: '供给类型'}]


  order:number; //order
  //提交表单
  onSubmit (e) {
    let data = {
      propertyName: e.propertyName,
      propertyValue: e.propertyValue,
      propertyType: e.propertyType,
      required: e.required=='true'? true: false,
      ruleName: e.ruleName,
      ruleValue: e.ruleValue,
      physicalUnit: e.physicalUnit,
      order: this.order,
      enabled: true,
      visible: true,
      tag: e.tag}
    this.data.propertyInfos.push(data)
    this.http.put(`/api/OptionalGroups/${this.data.id}`,this.data).subscribe(data=>{
      this.dialogRef.close('success')
    })
  }



}



//编辑消防设施模板可选分组属性
@Component({
  selector: 'app-editOptionalAttribute',
  templateUrl: './editOptionalAttribute.html',
  styleUrls: ['./fire-fighting-facilities-formwork.component.scss']
})
export class editOptionalAttributeComponent {

  constructor(private http:HttpClient,public dialogRef: MatDialogRef<editOptionalAttributeComponent>,
    @Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    this.propertyName = this.data.attribute.propertyName,
    this.propertyType = this.data.attribute.propertyType
    this.propertyValue = this.data.attribute.propertyValue,
    this.required = String(this.data.attribute.required),
    this.ruleName = this.data.attribute.ruleName,
    this.ruleValue = this.data.attribute.ruleValue,
    this.physicalUnit = this.data.attribute.physicalUnit,
    this.order = this.data.attribute.order,
    this.tag = this.data.attribute.tag
  }

  //定义属性数据
  type:Food[]=[
    {value:0, viewValue: '单行文本'},
    {value:1, viewValue: '多行文本'},
    {value:2, viewValue: '数值'},
    {value:3, viewValue: '图片'},
    {value:4, viewValue: '图片数量'},
    {value:5, viewValue: '方向'},
    {value:6, viewValue: '布尔值'},
    {value:7, viewValue: '供给区域'},
    {value:8, viewValue: '供给类型'}]

  propertyName:any; //属性名
  propertyType:number; //属性类型
  propertyValue:any; //默认值
  required:any; //是否必填
  ruleName:any; //验证规则
  ruleValue:any; //验证内容
  physicalUnit:any; //单位
  order:number; //order
  tag:any; //注释说明

  //提交表单
  onSubmit (e) {
    let data = {
      propertyName: e.propertyName,
      propertyValue: e.propertyValue,
      propertyType: e.propertyType,
      required: e.required=='true'? true: false,
      ruleName: e.ruleName,
      ruleValue: e.ruleValue,
      physicalUnit: e.physicalUnit,
      order: e.order,
      enabled: true,
      visible: true,
      tag: e.tag}
    this.data.grouping.propertyInfos.splice(this.data.grouping.propertyInfos.findIndex(item=>item==this.data.attribute),1)
    this.data.grouping.propertyInfos.push(data)
    this.http.put(`/api/OptionalGroups/${this.data.grouping.id}`,this.data.grouping).subscribe(data=>{
      this.dialogRef.close('success')
    })
  }



}