import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { MatTreeFlattener, MatTreeFlatDataSource } from '@angular/material/tree';
import { FlatTreeControl } from '@angular/cdk/tree';
import { MatSnackBar, MatSnackBarConfig } from '@angular/material/snack-bar';



@Component({
  selector: 'app-fire-fighting-template',
  templateUrl: './fire-fighting-template.component.html',
  styleUrls: ['./fire-fighting-template.component.scss']
})
export class FireFightingTemplateComponent implements OnInit {

  constructor(private http:HttpClient,public dialog: MatDialog,public snackBar: MatSnackBar) { }

  ngOnInit(): void {
    this.getAllFireFighting()
  }

  displayedColumns: string[] = ['name','operation'];
  aLLFireFighting:any; //所有消防要素模板

  //获取所有消防要素模板
  getAllFireFighting () {
    this.http.get('/api/FireCategories').subscribe(data=>{
      this.aLLFireFighting=data
    })
  }



  //新增消防模块窗口
  establish () {
    let dialogRef = this.dialog.open(NewFireFighting, 
      {
        width:'600px',
      });
    dialogRef.afterClosed().subscribe((data)=>{
      if (data) {this.getAllFireFighting()}
    }); 
  }

  //编辑消防模块窗口
  edit (e) {
    let dialogRef = this.dialog.open(EditFireClassification, 
      {
        width:'600px',
        data:{e}
      });
    dialogRef.afterClosed().subscribe((data)=>{
      if (data) {this.getAllFireFighting()}
    }); 
  }

  //启用
  enable (e) {
    this.http.put(`/api/FireCategories/${e.id}`,{
      id:e.id,
      name:e.name,
      enabled:true,
      fireElements:e.fireElements
    }).subscribe(data=>{
      this.getAllFireFighting()
    })
  }

  //禁用
  prohibit (e) {
    this.http.put(`/api/FireCategories/${e.id}`,{
      id:e.id,
      name:e.name,
      enabled:false,
      fireElements:e.fireElements
    }).subscribe(data=>{
      this.getAllFireFighting()
    })
  }

  //删除
  delete (e) {
    let isTrue = confirm('您确定要删除吗')
    if (isTrue) {
      this.http.delete(`/api/FireCategories/${e}`).subscribe(data=>{
        this.getAllFireFighting()
      })
    }
  }




}



//新增消防分类窗口
@Component({
  selector: 'app-newFireFighting',
  templateUrl: './newFireFighting.html',
  styleUrls: ['./fire-fighting-template.component.scss']
})
export class NewFireFighting {
  newdata = [];

  private _transformer = (node, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
      id: node.id,
      parentId: node.parentId,
      computed:node.computed,
      order:node.order,
      children:node.children ||'',
      tag:node.tag,
    };
  }
  treeControl = new FlatTreeControl<any>(node => node.level, node => node.expandable);
  treeFlattener = new MatTreeFlattener(this._transformer, node => node.level, node => node.expandable, node => node.children);
  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);

  constructor(private http:HttpClient,public snackBar: MatSnackBar,
    public dialogRef: MatDialogRef<NewFireFighting>) {}

  ngOnInit(): void { 
    this.rendering()
  }



  checkedAll:boolean=false; //全选
  checkedList:any=[]; //选中的消防要素

  //渲染Tree
  rendering () {
    this.http.get('/api/FireElements').subscribe((data:any)=>{
      this.newdata=[]
      function getparentNode(parentId){
        return data.find((item)=>{
          return item.id == parentId
        })
      }
      data.forEach(item => {
        var parentNode =  getparentNode(item.parentId);
        if(parentNode){
          if(!parentNode.children){
            parentNode.children = []
          }
          parentNode.children.push(item)
        }else{
          if(!item.parentId){
            this.newdata.push(item)
          }
        }
      });
    this.dataSource.data = this.newdata;
    this.treeControl.expandAll()
    })
  }
  hasChild = (_: number, node: any) => node.expandable;
  
  //change时判断是否选中
  changed (e,id) {
    if (e.checked) {
      this.checkedList.push(id)
    } else if (e.checked == false) {
      this.checkedList.splice(this.checkedList.findIndex(item => item === id), 1)
    }
  }



  //提交创建
  onSubmit (e) {
    if(this.checkedList.length) {
      this.http.post('/api/FireCategories',{
        name:e.name,
        enabled:true,
        fireElements:this.checkedList
      }).subscribe(data=>{
        this.dialogRef.close('success')
      })
    }else {
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请选择消防要素','确定',config);
    }
  }



}





//编辑消防分类窗口
@Component({
  selector: 'app-editingFire',
  templateUrl: './editingFireControl.html',
  styleUrls: ['./fire-fighting-template.component.scss']
})
export class EditFireClassification {
  newdata = [];

  private transformer = (node, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
      id: node.id,
      parentId: node.parentId,
      computed:node.computed,
      order:node.order,
      children:node.children ||'',
      tag:node.tag,
      checked:node.checked,
    };
  }
  treeControl = new FlatTreeControl<any>(node => node.level, node => node.expandable);
  treeFlattener = new MatTreeFlattener(this.transformer, node => node.level, node => node.expandable, node => node.children);
  newDataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);

  constructor(private http:HttpClient,public snackBar: MatSnackBar,
    public dialogRef: MatDialogRef<EditFireClassification>,
  @Inject(MAT_DIALOG_DATA) public newdate) {}

  ngOnInit(): void { 
    this.fireID=this.newdate.e.id
    this.fireName=this.newdate.e.name
    this.rendering()
  }



  fireID:any; //模板id
  fireName:any; //模板name
  checkedAll:boolean=false; //全选
  checkedList:any=[]; //选中的消防要素

  //渲染Tree
  rendering () {
    this.http.get(`/api/FireCategories/${this.newdate.e.id}/FireElements`).subscribe((data:any)=>{
      data.forEach(item=>{
        if (item.checked === true) {
          this.checkedList.push(item.id)
        }
      })
      this.newdata=[]
      function getparentNode(parentId){
        return data.find((item)=>{
          return item.id == parentId
        })
      }
      data.forEach(item => {
        var parentNode =  getparentNode(item.parentId);
        if(parentNode){
          if(!parentNode.children){
            parentNode.children = []
          }
          parentNode.children.push(item)
        }else{
          if(!item.parentId){
            this.newdata.push(item)
          }
        }
      });
    this.newDataSource.data = this.newdata;
    this.treeControl.expandAll()
    })
  }
  hasChild = (_: number, node: any) => node.expandable;
  
  //change时判断是否选中
  changed (e,id) {
    if (e.checked) {
      this.checkedList.push(id)
    } else if (e.checked == false) {
      this.checkedList.splice(this.checkedList.findIndex(item => item === id), 1)
    }
  }

  //提交编辑修改
  onSubmit (e) {
    if (this.checkedList.length) {
      this.http.put(`/api/FireCategories/${this.fireID}`,{
        id:this.fireID,
        name:e.name,
        enabled:this.newdate.e.enabled,
        fireElements:this.checkedList
      }).subscribe(data=>{
        this.dialogRef.close('success')
      })
    } else{
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请选择消防要素','确定',config);
    }
  }



}