import { Component, OnInit, Inject } from '@angular/core';
import { HttpClient } from '@angular/common/http';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { MatTreeFlattener, MatTreeFlatDataSource } from '@angular/material/tree';
import { FlatTreeControl } from '@angular/cdk/tree';

@Component({
  selector: 'app-fire-protection-elements',
  templateUrl: './fire-protection-elements.component.html',
  styleUrls: ['./fire-protection-elements.component.scss']
})
export class FireProtectionElementsComponent implements OnInit {
  data:any =[]
  newdata = [];

  private _transformer = (node, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
      id: node.id,
      parentId: node.parentId,
      computed:node.computed,
      order:node.order,
      children:node.children ||'',
      tag:node.tag
    };
  }
  treeControl = new FlatTreeControl<any>(node => node.level, node => node.expandable);
  treeFlattener = new MatTreeFlattener(this._transformer, node => node.level, node => node.expandable, node => node.children);
  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);
  
  constructor(private http:HttpClient,public dialog: MatDialog) { }

  ngOnInit(): void {
    this.getAllfireControl()
  }

  //获取所有消防要素
  getAllfireControl () {
    this.http.get('/api/FireElements').subscribe(
      (data:any)=>{
        this.newdata=[]
        function getparentNode(parentId){
          return data.find((item)=>{
            return item.id == parentId
          })
        }
        data.forEach(item => {
          var parentNode =  getparentNode(item.parentId);
          if(parentNode){
            if(!parentNode.children){
              parentNode.children = []
            }
            parentNode.children.push(item)
          }else{
            if(!item.parentId){
              this.newdata.push(item)
            }
          }
        });
        this.dataSource.data = this.newdata;
      }

    )
  }

  //更新数据后重新渲染Tree
  getlist = ():void=>{
    this.http.get('/api/FireElements').subscribe(
      (data:any)=>{
        this.newdata = []
        function getparentNode(parentId){
          return data.find((item)=>{
            return item.id == parentId
          })
        }
        data.forEach(item => {
          var parentNode =  getparentNode(item.parentId);
          if(parentNode){
            if(!parentNode.children){
              parentNode.children = []
            }
            parentNode.children.push(item)
          }else{
            if(!item.parentId){
              this.newdata.push(item)
            }
          }
        });

        const nodes = this.treeControl.dataNodes;
        const expandNodes = [];
        nodes.forEach((item) => {
          if(item.expandable && this.treeControl.isExpanded(item)){
            expandNodes.push(item.id);
          }
        });
        this.dataSource.data = this.newdata;
        let newNodes = this.treeControl.dataNodes;
        newNodes = newNodes.filter(n => {
          return expandNodes.indexOf(n.id) >= 0;
        });
        newNodes.forEach(item => {
          this.treeControl.expand(item);
        });
      }
    )
  }

  hasChild = (_: number, node: any) => node.expandable;

  //打开创建一级消防要素窗口
  addNew () {
    let dialogRef = this.dialog.open(Establish);
    dialogRef.afterClosed().subscribe((data)=>{
      if (data) {this.getlist()}
    }); 
  }

  //打开创建窗口
  establish (e) {
    let dialogRef = this.dialog.open(Establish, 
      {
        data:e
      });
    dialogRef.afterClosed().subscribe((data)=>{
      if (data) {this.getlist()}
    });   
  }

  //打开编辑窗口
  edit (e) {
    let dialogRef = this.dialog.open(EditingFireControl, 
      {
        data:e
      });
    dialogRef.afterClosed().subscribe((data)=>{
      if (data) {this.getlist()}
    });   
  }

  //取消统计
  noStatistics (e) {
    this.http.put(`/api/FireElements/${e.id}`,{
      expandable:e.expandable,
      id:e.id,
      name:e.name,
      level:e.level,
      order:e.order,
      computed:false,
      tag:e.tag,
      parentId:e.parentId,
      children:e.children
    }).subscribe(data=>{
      this.getlist()
    })
  }

  //确定统计
  statistics (e) {
    this.http.put(`/api/FireElements/${e.id}`,{
      expandable:e.expandable,
      id:e.id,
      name:e.name,
      level:e.level,
      order:e.order,
      computed:true,
      tag:e.tag,
      parentId:e.parentId,
      children:e.children
    }).subscribe(data=>{
      this.getlist()
    })
  }

  //删除
  delete (e) {
    let isTrue = confirm(`您确定要删除${e.name}吗`)
    if (isTrue) {
      this.http.delete(`/api/FireElements/${e.id}`).subscribe(data=>{
        this.getlist()
      })
    }
  }




}



//创建窗口组件
@Component({
  selector: 'app-establish',
  templateUrl: './establish.html',
  styleUrls: ['./fire-protection-elements.component.scss']
})
export class Establish {

  constructor(private http:HttpClient,
    public dialogRef: MatDialogRef<Establish>,
    @Inject(MAT_DIALOG_DATA) public data) {}

    ngOnInit(): void {}

    order:any; //创建消防要素order排序值

    //提交创建消防要素
    onSubmit (e) {
      if (this.data) {
        if(this.data.children == '') {
          this.order=0
        } else if (this.data.children.length) {
          this.order=this.data.children[this.data.children.length-1].order+1
        }
        this.http.post('/api/FireElements',{
          name:e.name,
          order:this.order,
          computed:e.radio,
          tag:e.tag,
          parentId:this.data.id
        }).subscribe(data=>{
          this.dialogRef.close('success')
        })
      } else {
        this.http.post('/api/FireElements',{
          name:e.name,
          order:0,
          computed:e.radio,
          tag:e.tag,
          parentId:null
        }).subscribe(data=>{
          this.dialogRef.close('success')
        })
      }

    }



}



//编辑窗口组件
@Component({
  selector: 'app-editingFireControl',
  templateUrl: './editingFireControl.html',
  styleUrls: ['./fire-protection-elements.component.scss']
})
export class EditingFireControl {

  constructor(private http:HttpClient,
    public dialogRef: MatDialogRef<EditingFireControl>,
    @Inject(MAT_DIALOG_DATA) public data) {}

    ngOnInit(): void {
      this.fireName=this.data.name
    }
    
    fireName:any; //消防要素name
  
    //编辑提交
    onSubmit (e) {
      this.http.put(`/api/FireElements/${this.data.id}`,{
        expandable:this.data.expandable,
        id:this.data.id,
        name:e.name,
        level:this.data.level,
        order:e.order,
        computed:this.data.computed,
        tag:this.data.tag,
        parentId:this.data.parentId,
        children:this.data.children
      }).subscribe(data=>{
        this.dialogRef.close('success')
      })
    }



  }
