import { Component, OnInit, Inject } from '@angular/core';
import { AddUnitInfo } from './addunitinfo.component'
import { EditUnitInfo } from './editunitinfo.component'
import { AddGroups } from './addgroups.component'
import { EditGroup } from './editgroup.component'
import { HttpClient } from '@angular/common/http';
import { MatDialog, MatDialogRef, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { MatSnackBar, MatSnackBarConfig } from '@angular/material/snack-bar';



@Component({
  selector: 'app-unit-information',
  templateUrl: './unit-information.component.html',
  styleUrls: ['./unit-information.component.scss']
})
export class UnitInformationComponent implements OnInit {

  constructor(private http:HttpClient,public dialog: MatDialog,public snackBar: MatSnackBar) { }

  ngOnInit(): void {
    this.http.get('/api/BasicCategories').subscribe(data=>{
      this.allUnitInformation = data
      this.unitInformation = data[0]
      this.getAllGrouping()})
  }

  allUnitInformation:any; //所有单位
  unitInformation:any={name:''}; //选中的单位
  unitInformationIndex:any=0; //选中的单位index

  allGrouping:any; //单位信息模板对应所有分组
  groupingSelect:any=[]; //选中的分组
  groupingIndex:any=[]; //选中的分组index
  attributeSelect:any=[]; //选中的分组属性
  attributeIndex:any=[]; //选中的分组属性所属分组index

  displayedColumns = ['checked', 'name', 'type', 'default','required','physicalUnit','operation'];

  isshow = true//左侧列表的显示隐藏
  //收起左侧列表 
  showlist(){
    this.isshow = !this.isshow
  }
  //获取所有的单位信息模板
  getAllUnitInformation () {
    this.http.get('/api/BasicCategories').subscribe(data=>{
      this.allUnitInformation = data
      this.unitInformation = data[this.unitInformationIndex]
    })
  }

  //单位信息模板对应所有分组
  getAllGrouping () {
    if (this.unitInformation) {
      let id = {categoryId:this.unitInformation.id}
      this.http.get('/api/BasicGroups',{params:id}).subscribe((data:any)=>{
        if (data.length) {
          data.forEach((item,index) => {
            if (item.name.indexOf('/')!=-1) {
              let str=item.name.substring(0,item.name.lastIndexOf('/'))
              if (str.indexOf('/')==-1 && index!=0 && data[index-1].name.indexOf(str) != -1 ) {
                item.css = true
              } else if (str.indexOf('/')!=-1 && index!=0 && data[index-1].name.indexOf(str) != -1 ){
                item.newcss = true
              }
            }
          });
        }
        this.allGrouping = data
        this.groupingSelect = []
        this.groupingIndex = []
        this.attributeSelect = []
        this.attributeIndex= []
        this.setIndex()
      })
    }
    
  }

  //选中单位
  add (e,index) {
    if (this.unitInformationIndex != index) {
      this.unitInformation = e
      this.unitInformationIndex = index
      this.getAllGrouping()
    }
  }

  //选中当前分组checked
  groupingChange (e,index,event) {
    if (event.checked === true) {
        this.groupingSelect.push(e)
        this.groupingIndex.push(index)
    } else {
      this.groupingSelect.splice(this.groupingSelect.findIndex(item => item.id == e.id), 1)
      this.groupingIndex.splice(this.groupingIndex.findIndex(items => items == index), 1)
    }
  }

  //分组上移
  groupingTop () {
    if (this.groupingSelect.length && this.groupingIndex.length) {
      let select = this.groupingSelect[this.groupingSelect.length-1]
      let index = this.groupingIndex[this.groupingIndex.length-1]
      if (index!=0) {
        let topOrder = this.allGrouping[index].order
        let bottomOrder = this.allGrouping[index-1].order
        this.allGrouping[index-1].order = topOrder
        this.allGrouping.forEach(item => {
          item.propertyInfos.forEach((element) => {
            delete element.index
          });
        });
        this.http.put(`/api/BasicGroups/${this.allGrouping[index-1].id}`,{
          id:this.allGrouping[index-1].id,
          name:this.allGrouping[index-1].name,
          type:this.allGrouping[index-1].type,
          addMode:this.allGrouping[index-1].addMode,
          isOptional:this.allGrouping[index-1].isOptional,
          order:this.allGrouping[index-1].order,
          enabled:this.allGrouping[index-1].enabled,
          propertyInfos:this.allGrouping[index-1].propertyInfos,
          basicCategoryId:this.allGrouping[index-1].basicCategoryId
        }).subscribe(data=>{
          this.allGrouping[index].order = bottomOrder
          this.submit(select,index)
        })
      }
    }
  }

  //分组下移
  groupingBottom () {
    if (this.groupingSelect.length && this.groupingIndex.length) {
      let select = this.groupingSelect[this.groupingSelect.length-1]
      let index = this.groupingIndex[this.groupingIndex.length-1]
      if (index!=this.allGrouping.length-1) {
        let topOrder = this.allGrouping[index].order
        let bottomOrder = this.allGrouping[index+1].order
        this.allGrouping[index+1].order = topOrder
        this.allGrouping.forEach(item => {
          item.propertyInfos.forEach((element) => {
            delete element.index
          });
        });
        this.http.put(`/api/BasicGroups/${this.allGrouping[index+1].id}`,{
          id:this.allGrouping[index+1].id,
          name:this.allGrouping[index+1].name,
          type:this.allGrouping[index+1].type,
          addMode:this.allGrouping[index+1].addMode,
          isOptional:this.allGrouping[index+1].isOptional,
          order:this.allGrouping[index+1].order,
          enabled:this.allGrouping[index+1].enabled,
          propertyInfos:this.allGrouping[index+1].propertyInfos,
          basicCategoryId:this.allGrouping[index+1].basicCategoryId
        }).subscribe(data=>{
          this.allGrouping[index].order = bottomOrder
          this.submit(select,index)
        })
      }
    }
  }

  //新增单位
  addunitinfo(){
    const dialogRef = this.dialog.open(AddUnitInfo, {//调用open方法打开对话框并且携带参数过去
      width: '260px',
      data: {}
    });
    dialogRef.afterClosed().subscribe(
      data=>{
        if(data){
          this.getAllUnitInformation ()
        }
          
      }
    );
  }

  //编辑单位
  editunitinfo(){
    if(this.unitInformation){
      const dialogRef = this.dialog.open(EditUnitInfo, {//调用open方法打开对话框并且携带参数过去
        width: '295px',
        data: {unitInformation:this.unitInformation}
      });
      dialogRef.afterClosed().subscribe(
        data=>{
          if(data){
            this.getAllUnitInformation ()
          } 
        }
      );
    }else{
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请先选择单位','确定',config);
    }
  }

  //禁启用单位
  disableunit(){
    if(this.unitInformation){
      this.http.put(`/api/BasicCategories/${this.unitInformation.id}`,{
        id: this.unitInformation.id,
        name: this.unitInformation.name, 
        enabled: !this.unitInformation.enabled,
    }).subscribe(data=>{
      this.getAllUnitInformation ()
    })
    }else{
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请先选择单位','确定',config);
    }
  }

  //删除单位
  deleteunit(){
    var isdeleted = confirm(`确定要删除${this.unitInformation.name}单位信息吗？`)
    if(isdeleted){
      //请求删除接口
      this.http.delete(`/api/BasicCategories/${this.unitInformation.id}`).subscribe( data=>{ 
        this.http.get('/api/BasicCategories').subscribe(data=>{
          this.allUnitInformation = data
          this.unitInformation = data[this.unitInformationIndex]
          this.getAllGrouping()})
      })
    }
  }

  //新增分组
  addgroups(){
    const dialogRef = this.dialog.open(AddGroups, {//调用open方法打开对话框并且携带参数过去
      width: '295px',
      data: {unitInformation:this.unitInformation,allGrouping:this.allGrouping}
    });
    dialogRef.afterClosed().subscribe(
      msg=>{
        if(msg && msg!='yes'){
            msg.forEach((item,index) => {
              this.http.put(`/api/BasicGroups/${item.id}`,{
                id: item.id,
                name: item.name,
                type:item.type,
                addMode:item.addMode,
                isOptional:item.isOptional,
                order: index,
                enabled: item.enabled,
                propertyInfos:item.propertyInfos,
                basicCategoryId: item.basicCategoryId
              }).subscribe(data=>{
                if (index===msg.length-1) {this.getAllGrouping()}
              })
            });
            // this.getAllGrouping()
        } else if (msg == 'yes') {this.getAllGrouping()}

      }



    );
  }

  //编辑分组
  editgroup(item,index){
    const dialogRef = this.dialog.open(EditGroup, {//调用open方法打开对话框并且携带参数过去
      width: '295px',
      data: {unitInformation:this.unitInformation,allGrouping:this.allGrouping,item:item}
    });
    dialogRef.afterClosed().subscribe(
      data=>{
        if(data){
          this.getAllGrouping ()
        } 
      }
    );
  }

  //禁启用分组
  disablegroup(item){
    if(item.enabled){
      this.http.put(`/api/BasicGroups/${item.id}`,{
        id: item.id,
        name: item.name,
        type:item.type,
        addMode:item.addMode,
        isOptional:item.isOptional,
        order: item.order,
        enabled: false,
        propertyInfos:item.propertyInfos,
        basicCategoryId: item.basicCategoryId
      }).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('禁用成功','确定',config);
        this.getAllGrouping ()
      })
    }else{
      this.http.put(`/api/BasicGroups/${item.id}`,{
        id: item.id,
        name: item.name,
        type:item.type,
        addMode:item.addMode,
        isOptional:item.isOptional,
        order: item.order,
        enabled: true,
        propertyInfos:item.propertyInfos,
        basicCategoryId: item.basicCategoryId
      }).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('启用成功','确定',config);
        this.getAllGrouping ()
      })
    }
  }

  //设置是否分组可选
  optional (item) {
    if (item.isOptional) {
      this.http.put(`/api/BasicGroups/${item.id}`,{
        id: item.id,
        name: item.name,
        type:item.type,
        addMode:item.addMode,
        isOptional:false,
        order: item.order,
        enabled: item.enabled,
        propertyInfos:item.propertyInfos,
        basicCategoryId: item.basicCategoryId
      }).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('现状态为不可选','确定',config);
        this.getAllGrouping ()
      })
    } else{
      this.http.put(`/api/BasicGroups/${item.id}`,{
        id: item.id,
        name: item.name,
        type:item.type,
        addMode:item.addMode,
        isOptional:true,
        order: item.order,
        enabled: item.enabled,
        propertyInfos:item.propertyInfos,
        basicCategoryId: item.basicCategoryId
      }).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('现状态为可选','确定',config);
        this.getAllGrouping ()
      })
    }
  }

  //删除分组
  deletegroup(item){
    var isdeleted = confirm(`确定要删除${item.name}分组吗？`)
    if(isdeleted){
      //请求删除接口
      this.http.delete(`/api/BasicGroups/${item.id}`).subscribe( data=>{ 
        this.getAllGrouping ()
      })
    }
  }





  //分组属性操作↓
  //选中分组属性checked
  attributeChange (item,index,event) {
    if (event.checked === true) {
      this.attributeSelect.push(item)
      this.attributeIndex.push(index)
    } else {
      this.attributeSelect.splice(this.attributeSelect.findIndex(items => items == item), 1)
      this.attributeIndex.splice(this.attributeIndex.findIndex(items => items == index), 1)
    }
  }

  //属性上移
  attributeTop (e,index) {
    let select = this.attributeSelect[this.attributeSelect.length-1]
    let newIndex = this.attributeIndex[this.attributeIndex.length-1] 
    if (this.attributeSelect.length && newIndex===index) {
      let newOrder = this.attributeSelect[this.attributeSelect.length-1].order
      if(select.index != 0) {
        this.allGrouping[index].propertyInfos[select.index].order=this.allGrouping[index].propertyInfos[select.index-1].order
        this.allGrouping[index].propertyInfos[select.index-1].order=newOrder
        this.submit(e,index)
      }
    }
  }

  //属性下移
  attributeBottom (e,index) {
    let select = this.attributeSelect[this.attributeSelect.length-1]
    let newIndex = this.attributeIndex[this.attributeIndex.length-1] 
    if (this.attributeSelect.length && newIndex===index) {
      let newOrder = this.attributeSelect[this.attributeSelect.length-1].order
      if(select.index != this.allGrouping[index].propertyInfos.length-1) {
        this.allGrouping[index].propertyInfos[select.index].order=this.allGrouping[index].propertyInfos[select.index+1].order
        this.allGrouping[index].propertyInfos[select.index+1].order=newOrder
        this.submit(e,index)
      }
    }
  }

  //封装函数每条属性添加index
  setIndex () {
    if (this.allGrouping.length) {
      this.allGrouping.forEach(item => {
        item.propertyInfos.forEach((element,index) => {
          element.index = index
        });
      });
    }
  }

  //创建分组属性
  addGrouping (e,index) {
    let data = e
    const dialogRef = this.dialog.open(addUnitAttributeComponent,{data});
    dialogRef.afterClosed().subscribe(
      data=>{ if (data) {
        this.allGrouping[index].propertyInfos.push(data)
        this.submit(e,index)
      }})
  }

  //编辑分组属性
  editGrouping (e,index,element) {
    let data = element
    const dialogRef = this.dialog.open(editUnitAttribute,{data});
    dialogRef.afterClosed().subscribe(
      data=>{ if (data) {
        this.allGrouping[index].propertyInfos[data.index] = data
        this.submit(e,index)
      }})
  }

  //属性显示
  display (e) {
    e.visible = true
  }

  //属性隐藏
  noDisplay (e) {
    e.visible = false
  }

  //属性启用
  enabledGrouping (e) {
    e.enabled = true
  }
  
  //属性禁用
  noEnabledGrouping (e) {
    e.enabled = false
  }

  //属性删除
  deleteGrouping (e,index,elementIndex) {
    let isTrue = confirm('您确定要删除吗')
    if (isTrue) {
      this.allGrouping[index].propertyInfos.splice(elementIndex,1)
      this.submit(e,index)
    }
  }



  //提交当前分组保存数据
  submit (e,index) {
    if (this.allGrouping.length) {
      this.allGrouping.forEach(item => {
        item.propertyInfos.forEach((element) => {
          delete element.index
        });
      });
      this.http.put(`/api/BasicGroups/${e.id}`,{
        id:e.id,
        name:e.name,
        type:e.type,
        addMode:e.addMode,
        isOptional: e.isOptional,
        order:e.order,
        enabled:e.enabled,
        propertyInfos:this.allGrouping[index].propertyInfos,
        basicCategoryId:e.basicCategoryId
      }).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('数据更新成功','确定',config);
        this.getAllGrouping()
      })
    } else {
      this.http.put(`/api/BasicGroups/${e.id}`,{
        id:e.id,
        name:e.name,
        type:e.type,
        addMode:e.addMode,
        isOptional:e.isOptional,
        order:e.order,
        enabled:e.enabled,
        propertyInfos:this.allGrouping[index].propertyInfos,
        basicCategoryId:e.basicCategoryId
      }).subscribe(data=>{
        const config = new MatSnackBarConfig();
        config.verticalPosition = 'top';
        config.duration = 3000
        this.snackBar.open('数据更新成功','确定',config);
        this.getAllGrouping()
      })
    }
  }



}



//新增属性弹窗
export interface Food {
  value: number;
  viewValue: string;
}
@Component({
  selector: 'app-addUnitAttribute',
  templateUrl: './addUnitAttribute.html',
  styleUrls: ['./unit-information.component.scss']
})
export class addUnitAttributeComponent {

  constructor(private http:HttpClient,public dialog: MatDialog,
    public dialogRef: MatDialogRef<addUnitAttributeComponent>,@Inject(MAT_DIALOG_DATA) public data) { }

  ngOnInit(): void {
    if (this.data.propertyInfos.length) {
      this.order = this.data.propertyInfos[this.data.propertyInfos.length-1].order +1
    } else {
      this.order = 0
    }
  }

  //定义属性数据
  propertyType:Food[]=[
    {value:0, viewValue: '单行文本'},
    {value:1, viewValue: '多行文本'},
    {value:2, viewValue: '数值'},]

  order:number; //order

  //提交表单
  onSubmit (e) {
    e.order = this.order
    e.enabled = true
    e.visible = true
    e.required = e.required=='true'? true: false,
    this.dialogRef.close(e)
  }



}



//编辑属性弹窗
@Component({
  selector: 'app-editUnitAttribute',
  templateUrl: './editUnitAttribute.html',
  styleUrls: ['./unit-information.component.scss']
})
export class editUnitAttribute {

  constructor(private http:HttpClient,public dialog: MatDialog,
    public dialogRef: MatDialogRef<editUnitAttribute>,
    @Inject(MAT_DIALOG_DATA) public data,) { }

  ngOnInit(): void {
      this.propertyName = this.data.propertyName
      this.propertyValue = this.data.propertyValue
      this.propertyType = this.data.propertyType
      this.required = String(this.data.required)
      this.ruleName = this.data.ruleName
      this.ruleValue = this.data.ruleValue
      this.physicalUnit = this.data.physicalUnit
      this.tag = this.data.tag
      this.order = this.data.order}



  propertyName:any
  propertyValue:any;
  propertyType:number;
  required:any;
  ruleName:any;
  ruleValue:any;
  physicalUnit:any;
  tag:any;
  order:number;

  //定义属性数据
  type:Food[]=[
    {value:0, viewValue: '单行文本'},
    {value:1, viewValue: '多行文本'},
    {value:2, viewValue: '数值'},]

  //提交表单
  onSubmit (e) {
    e.enabled = this.data.enabled
    e.visible = this.data.visible
    e.index = this.data.index
    e.required = e.required=='true'? true: false,
    this.dialogRef.close(e)
  }



}
