import { Component, OnInit, Inject } from '@angular/core';
import {HttpClient} from '@angular/common/http'
import { MatDialogRef, MatDialog, MAT_DIALOG_DATA } from '@angular/material/dialog';
import { FlatTreeControl } from '@angular/cdk/tree';
import { MatTreeFlattener, MatTreeFlatDataSource } from '@angular/material/tree';
import { MatSnackBar, MatSnackBarConfig } from '@angular/material/snack-bar';



@Component({
  selector: 'app-unittype',
  templateUrl: './unittype.component.html',
  styleUrls: ['./unittype.component.scss']
})
export class UnittypeComponent implements OnInit {

  constructor(public http: HttpClient,public dialog: MatDialog,public snackBar: MatSnackBar) { }

  displayedColumns: string[]=['company', 'template','fireControl','facilityCategory','operation'];
  dataSource:any=[];  //所有单位类型
  allFireControl:any=[]; //所有消防要素模板

  ngOnInit() {
    this.getList()
    this.getFireControl()
  }
  

  //获取所有单位类型
  getList () {
    this.http.get('/api/BuildingTypes').subscribe(
      (data: any[]) => {
        this.dataSource=data
      }
    )
  }

  //获取所有消防要素模板
  getFireControl () {
    this.http.get('/api/FireCategories').subscribe(
      (data:any)=>{
        this.allFireControl=data
    }
  )}

  //创建单位弹窗
  open() {
    let data = this.allFireControl || []
    let dialogRef = this.dialog.open(DialogOverviewExampleDialog,{data});
      dialogRef.afterClosed().subscribe(
        (data)=>{if (data) {this.getList()}}
      );
  }

  //编辑弹窗
  edit (e) {
    let data= e
    let allFireControl= this.allFireControl || []
    let dialogRef = this.dialog.open(editorialUnit,
      {      
        width:"260px",
       data:{data,allFireControl}
      });
      dialogRef.afterClosed().subscribe(
        (data)=>{if (data) {this.getList()}}
      );
  }

  //启用
  enabled(e) {
    this.http.put(
   `/api/BuildingTypes/${e.id}`,
   {
     id:e.id,
     name: e.name,
     enabled: true,
     basicCategoryId:e.basicCategoryId,
     fireCategoryId:e.fireCategoryId,
     facilityCategoryId: e.facilityCategoryId,
  }
   ).subscribe(
      ()=> {
        this.getList()
      }
    )
  }

  //禁用
  prohibit (e) {
    this.http.put(
      `/api/BuildingTypes/${e.id}`,
      {
        id:e.id,
        name: e.name,
        enabled: false,
        basicCategoryId:e.basicCategoryId,
        fireCategoryId:e.fireCategoryId,
        facilityCategoryId: e.facilityCategoryId,
      }
      ).subscribe(
         ()=> {
          this.getList()
         }
       )
  }

  //删除
  delete(e) {
    let isTrue = confirm('您确定要删除吗')
    if(isTrue) {
      this.http.delete(`/api/BuildingTypes/${e}`).subscribe(
        ()=>{
          this.getList()
        }
      )
    }
  }


  
}

//创建单位弹窗组件
@Component({
  selector: 'dialog-overview-example-dialog',
  templateUrl: 'dialog-overview-example-dialog.html',
  styleUrls: ['./unittype.component.scss']
})
export class DialogOverviewExampleDialog {
  data:any =[]
  newdata = [];

  private _transformer = (node, level: number) => {
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
      id: node.id,
      parentId: node.parentId,
      computed:node.computed,
      order:node.order,
      checked:node.checked,
      tag:node.tag
    };
  }
  treeControl = new FlatTreeControl<any>(node => node.level, node => node.expandable);
  treeFlattener = new MatTreeFlattener(this._transformer, node => node.level, node => node.expandable, node => node.children);
  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);
  
  constructor(public http: HttpClient,public snackBar: MatSnackBar,
  public dialogRef: MatDialogRef<DialogOverviewExampleDialog>,
  @Inject(MAT_DIALOG_DATA) public allFireControl) {}

  ngOnInit() {
    this.getunitmsg()
    this.getAllFacilityCategory()
  }

  oldSelected:any; //选中的单位信息模板id
  selected:any; //选中的消防要素模板id
  allunitmsg:any //所有单位信息
  allFacilityCategory:any; //所有消防设施模板

  //获得所有单位信息模板
  getunitmsg(){
    this.http.get('/api/BasicCategories').subscribe(data=>{
      this.allunitmsg = data
    })
  }

  //获取所有消防设施模板
  getAllFacilityCategory () {
    this.http.get('/api/FacilityCategories').subscribe(data=>{
      this.allFacilityCategory = data
    })
  }

  //封装实现select框切换渲染更新Tree函数
  select () {
    this.newdata=[]
    let id = this.selected
    this.http.get(`/api/FireCategories/${id}/FireElements`).subscribe(
      (data:any)=>{
        function getparentNode(parentId){
          return data.find((item)=>{
            return item.id == parentId
          })
        }
        data.forEach(item => {
          var parentNode =  getparentNode(item.parentId);
          if(parentNode){
            if(!parentNode.children){
              parentNode.children = []
            }
            parentNode.children.push(item)
          }else{
            if(!item.parentId){
              this.newdata.push(item)
            }
          }
        });
        this.dataSource.data = this.newdata;
      }
    )

  }

  //select选择切换Tree
  toggleDisplay() {
    this.select()
  }

  hasChild = (_: number, node: any) => node.expandable;
  
  //创建单位类型
  onSubmit (e) {
    if(this.selected) {
      this.http.post('/api/BuildingTypes',{
        name:e.name,
        enabled:true,
        basicCategoryId:e.basicCategoryName,
        fireCategoryId:this.selected,
        facilityCategoryId: e.facilityCategoryName
      }).subscribe(data=>{
        this.dialogRef.close('success')
      })
    } else {
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请填写完整','确定',config);
    }
  }



}


//编辑单位弹窗组件
@Component({
  selector: 'app-editorialUnit',
  templateUrl: './editorialUnit.html',
  styleUrls: ['./unittype.component.scss']
})
export class editorialUnit {

constructor(public http: HttpClient,public snackBar: MatSnackBar,
  public dialogRef: MatDialogRef<DialogOverviewExampleDialog>,
  @Inject(MAT_DIALOG_DATA) public data) {}

  ngOnInit() {
    this.companyName=this.data.data.name
    this.oldSelected = this.data.data.basicCategoryId
    this.selected=this.data.data.fireCategoryId
    this.facilityCategoryId = this.data.data.facilityCategoryId
    this.getunitmsg()
    this.getAllFacilityCategory()
  }

  companyName:any; //单位类型name
  oldSelected:any; //单位信息模板id
  selected:any; //消防要素模板id
  facilityCategoryId:any; //消防设施模板id
  allunitmsg:any //所有单位信息模板
  allFacilityCategory:any; //所有消防设施模板

  //获得所有单位信息模板
  getunitmsg(){
    this.http.get('/api/BasicCategories').subscribe(data=>{
      this.allunitmsg = data
    })
  }

  //获取所有消防设施模板
  getAllFacilityCategory () {
    this.http.get('/api/FacilityCategories').subscribe(data=>{
      this.allFacilityCategory = data
    })
  }
  
  //编辑功能
  onSubmit (e) {
    let id = this.data.data.id
    let enabled = this.data.data.enabled
    if(e.name&&this.selected&&this.oldSelected) {
      this.http.put(`/api/BuildingTypes/${id}`,{
        id:id,
        name:e.name,
        enabled: enabled,
        basicCategoryId:this.oldSelected,
        fireCategoryId:this.selected,
        facilityCategoryId: e.facilityCategoryName
      }).subscribe(data=>{
        this.dialogRef.close('success')
      })
    } else {
      const config = new MatSnackBarConfig();
      config.verticalPosition = 'top';
      config.duration = 3000
      this.snackBar.open('请填写完整','确定',config);
    }
  }



}
