const mapSupplier: number = 1; // 1:高德, 2:科达

import { IMap, IMapOptions, IMarker, IPixel, IMarkOptions, ILngLat, ILayer, ICircle, IMarkerCluster, IRenderClusterMarker, IInfoWindow, IMouseTool, IIcon, ISize, IIconOptions, ITileLayer, IDriving, IDrivingOptions, IAutocomplete, IPlaceSearch } from './map'
import { GaodeCircle, GaodeIcon, GaodeInfoWindow, GaodeLayer, GaoDeLngLat, GaoDeMap, GaoDeMarker, GaoDeMarkerCluster, GaodeMouseTool, GaoDePixel, GaoDeRenderClusterMarker, GaodeTileLayer, GaodeSize, GaodeDriving, GaodeAutocomplete, GaodePlaceSearch } from './gaode-map'
import { KedaAutocomplete, KedaCircle, KedaDriving, KedaInfoWindow, KedaLayer, KeDaLngLat, KeDaMap, KeDaMarker, KedaMarkerCluster, KedaMouseTool, KeDaPixel, KedaPlaceSearch, KedaRenderClusterMarkerr, KedaTileLayer } from './keda-map';
import MapTools from './map-tools';

export class MapFactory {
    public static MapInstance(container: string, options: IMapOptions | any,plugins?:string[]): IMap {
        let config = MapTools.ExplicitConvert(options);
        switch (mapSupplier) {
            case 1: return new GaoDeMap(container, config,plugins);
            case 2: return new KeDaMap(container, config);
            default: return null;
        }
    }

    public static PixelInstance(x: number, y: number): IPixel {
        switch (mapSupplier) {
            case 1: return new GaoDePixel(x, y);
            case 2: return new KeDaPixel(x, y);
            default: return null;
        }
    }
    public static MarkerInstance(options: IMarkOptions): IMarker {
        switch (mapSupplier) {
            case 1: return new GaoDeMarker(options);
            case 2: return new KeDaMarker(options);
            default: return null;
        }
    }

    public static MarkerClusterInstance(map: IMap, list: Object[], renderObj: { gridSize: number, render: IRenderClusterMarker ,maxZoom: number}): IMarkerCluster {
        switch (mapSupplier) {
            case 1: return new GaoDeMarkerCluster(map, list, renderObj);
            case 2: return new KedaMarkerCluster(map, list, renderObj);
            default: return null;
        }
    }

    public static LngLatInstance(x: number, y: number): ILngLat {
        switch (mapSupplier) {
            case 1: return new GaoDeLngLat(x, y);
            case 2: return new KeDaLngLat(x, y);
            default: return null;
        }
    }

    public static IconInstance(options: IIconOptions): IIcon { //科达map 暂不需要
        switch (mapSupplier) {
            case 1: return new GaodeIcon(options);
            default: return null;
        }
    }

    public static SizeInstance(x: number, y: number): ISize { //科达map 暂不需要
        switch (mapSupplier) {
            case 1: return new GaodeSize(x, y);
            default: return null;
        }
    }

    public static TileLayerInstance(): ITileLayer {
        switch (mapSupplier) {
            case 1: return new GaodeTileLayer();
            case 2: return new KedaTileLayer();
            default: return null;
        }
    }

    public static LayerInstance(options: any): ILayer {
        switch (mapSupplier) {
            case 1: return new GaodeLayer(options);
            case 2: return new KedaLayer(options);
            default: return null;
        }
    }

    public static DrivingInstance(options: IDrivingOptions): IDriving {
        switch (mapSupplier) {
            case 1: return new GaodeDriving(options);
            case 2: return new KedaDriving(options);
            default: return null;
        }
    }

    public static AutocompleteInstance(options: any,component: any): IAutocomplete {
        switch (mapSupplier) {
            case 1: return new GaodeAutocomplete(options,component);
            case 2: return new KedaAutocomplete(options,component);
            default: return null;
        }
    }

    public static PlaceSearchInstance(component: any): IPlaceSearch {
        switch (mapSupplier) {
            case 1: return new GaodePlaceSearch(component);
            case 2: return new KedaPlaceSearch(component);
            default: return null;
        }
    }

    public static MouseToolInstance(map: IMap): IMouseTool {
        switch (mapSupplier) {
            case 1: return new GaodeMouseTool(map);
            case 2: return new KedaMouseTool(map);
            default: return null;
        }
    }

    public static InfoWindowInstance(options: any): IInfoWindow {
        switch (mapSupplier) {
            case 1: return new GaodeInfoWindow(options);
            case 2: return new KedaInfoWindow(options);
            default: return null;
        }
    }

    public static CircleInstance(options: any): ICircle {
        switch (mapSupplier) {
            case 1: return new GaodeCircle(options);
            case 2: return new KedaCircle(options);
            default: return null;
        }
    }

    public static RenderClusterMarkerInstance(): IRenderClusterMarker {
        switch (mapSupplier) {
            case 1: return new GaoDeRenderClusterMarker();
            case 2: return new KedaRenderClusterMarkerr();
            default: return null;
        }
    }

}